@@ -27,7 +27,7 @@ module Facter
     include Comparable
     include Enumerable
 
-    FACTERVERSION = '1.5.6'
+    FACTERVERSION = '1.5.8'
     # = Facter
     # Functions as a hash of 'facts' you might care about about your
     # system, such as mac address, IP address, Video card, etc.
@@ -68,11 +68,15 @@ module Facter
         if string.nil?
             return
         end
-        if @@debug != 0
+        if self.debugging?
             puts GREEN + string + RESET
         end
     end
 
+    def self.debugging?
+        @@debug != 0
+    end
+
     # Return a fact object by name.  If you use this, you still have to call
     # 'value' on it to retrieve the actual value.
     def self.[](name)
@@ -120,7 +124,7 @@ module Facter
                 name = name.to_s.sub(/\?$/,'')
             end
 
-            if fact = @collection.fact(name)
+            if fact = collection.fact(name)
                 if question
                     value = fact.value.downcase
                     args.each do |arg|
@@ -173,6 +177,14 @@ module Facter
         end
     end
 
+
+    def self.warn(msg)
+        if Facter.debugging? and msg and not msg.empty?
+            msg = [msg] unless msg.respond_to? :each
+            msg.each { |line| Kernel.warn line }
+        end
+    end
+
     # Remove them all.
     def self.reset
         @collection = nil
